@@ -15,7 +15,7 @@ Usage (cli):
 
     $ dig example.com | jc --dig
 
-    or
+or
 
     $ jc dig example.com
 
@@ -24,11 +24,6 @@ Usage (module):
     import jc
     result = jc.parse('dig', dig_command_output)
 
-    or
-
-    import jc.parsers.dig
-    result = jc.parsers.dig.parse(dig_command_output)
-
 Schema:
 
     [
@@ -106,7 +101,7 @@ Schema:
     ]
 
     [0] naive timestamp if "when" field is parsable, else null
-    [1] timezone aware timestamp availabe for UTC, else null
+    [1] timezone aware timestamp available for UTC, else null
 
 Examples:
 
@@ -327,12 +322,13 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '2.3'
+    version = '2.4'
     description = '`dig` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'aix', 'freebsd', 'darwin', 'win32', 'cygwin']
     magic_commands = ['dig']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -350,9 +346,10 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'id', 'query_num', 'answer_num', 'authority_num', 'additional_num',
+                    'rcvd', 'query_size', 'query_time'}
+
     for entry in proc_data:
-        int_list = ['id', 'query_num', 'answer_num', 'authority_num', 'additional_num',
-                    'rcvd', 'query_size', 'query_time']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
