@@ -1,5 +1,7 @@
 """jc - JSON Convert `YAML` file parser
 
+> Note: `datetime` objects will be converted to strings.
+
 Usage (cli):
 
     $ cat foo.yaml | jc --yaml
@@ -85,12 +87,13 @@ from jc.exceptions import LibraryNotInstalled
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.6'
+    version = '1.7'
     description = 'YAML file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     details = 'Using the ruamel.yaml library at https://pypi.org/project/ruamel.yaml'
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
+    tags = ['standard', 'file', 'string']
 
 
 __version__ = info.version
@@ -147,6 +150,11 @@ def parse(data, raw=False, quiet=False):
 
         yaml = YAML(typ='safe')
 
+        # modify the timestamp constructor to output datetime objects as
+        # strings since JSON does not support datetime objects
+        yaml.constructor.yaml_constructors['tag:yaml.org,2002:timestamp'] = \
+            yaml.constructor.yaml_constructors['tag:yaml.org,2002:str']
+
         for document in yaml.load_all(data):
             raw_output.append(document)
 
